<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */

/**
 * Get the bootstrap! If using the plugin from wordpress.org, REMOVE THIS!
 */

if ( file_exists( dirname( __FILE__ ) . '/cmb2/init.php' ) ) {
	require_once dirname( __FILE__ ) . '/cmb2/init.php';
} elseif ( file_exists( dirname( __FILE__ ) . '/CMB2/init.php' ) ) {
	require_once dirname( __FILE__ ) . '/CMB2/init.php';
}

/**
 * Conditionally displays a metabox when used as a callback in the 'show_on_cb' cmb2_box parameter
 *
 * @param  CMB2 object $cmb CMB2 object
 *
 * @return bool             True if metabox should show
 */
function h5vp_yourprefix_show_if_front_page( $cmb ) {
	// Don't show this metabox if it's not the front page template
	if ( $cmb->object_id !== get_option( 'page_on_front' ) ) {
		return false;
	}
	return true;
}

/**
 * Conditionally displays a field when used as a callback in the 'show_on_cb' field parameter
 *
 * @param  CMB2_Field object $field Field object
 *
 * @return bool                     True if metabox should show
 */
function h5vp_yourprefix_hide_if_no_cats( $field ) {
	// Don't show this field if not in the cats category
	if ( ! has_tag( 'cats', $field->object_id ) ) {
		return false;
	}
	return true;
}

/**
 * Conditionally displays a message if the $post_id is 2
 *
 * @param  array             $field_args Array of field parameters
 * @param  CMB2_Field object $field      Field object
 */
function h5vp_yourprefix_before_row_if_2( $field_args, $field ) {
	if ( 2 == $field->object_id ) {
		echo '<p>Testing <b>"before_row"</b> parameter (on $post_id 2)</p>';
	} else {
		echo '<p>Testing <b>"before_row"</b> parameter (<b>NOT</b> on $post_id 2)</p>';
	}
}

add_action( 'cmb2_admin_init', 'h5vp_yourprefix_register_demo_metabox' );
/**
 * Hook in and add a demo metabox. Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */
function h5vp_yourprefix_register_demo_metabox() {

	// Start with an underscore to hide fields from custom fields list
	$prefix = 'msb_';

	/**
	 * Sample metabox to demonstrate each field type included
	 */
	$cmb_demo = new_cmb2_box( array(
		'id'            => $prefix . 'metabox2',
		'title'         => __( 'Set up skype button' ),
		'object_types'  => array( 'skypebutton', ), // Post type
		// 'show_on_cb' => 'yourprefix_show_if_front_page', // function should return a bool value
		// 'context'    => 'normal',
		   'priority'   => 'high',
		// 'show_names' => true, // Show field names on the left
		// 'cmb_styles' => false, // false to disable the CMB stylesheet
		// 'closed'     => true, // true to keep the metabox closed by default
	) );


	$cmb_demo->add_field( array(
		'name' => __( 'Skype ID (required)', 'cmb2' ),
		'desc' => __( 'Enter skype Id here here.', 'cmb2' ),
		'id'   => $prefix . 'skype_id',
		'type' => 'text',
	) );
	
	$cmb_demo->add_field( array(
		'name' => __( 'Button Size (optional)', 'cmb2' ),
		'desc' => __( 'You can change the button size here.', 'cmb2' ),
		'id'   => $prefix . 'button_size',
		'type' => 'select',
		'default' => '16',
		'options'          => array(
			'10' => __( '10 px', '' ),
			'12' => __( '12 px', '' ),
			'14' => __( '14 px', '' ),
			'16' => __( '16 px', '' ),
			'24' => __( '24 px', '' ),
			'32' => __( '32 px', 'loop' ),
		),		
	) );

	$cmb_demo->add_field( array(
		'name'             => __( 'Button Color (optional)', 'cmb2' ),
		'desc'             => __( 'Display White color button', 'cmb2' ),
		'id'               => $prefix . 'button_color',
		'type'             => 'checkbox',	
	) );


	$cmb_demo->add_field( array(
		'name' => __( 'Button Type (optional)', 'cmb2' ),
		'desc' => __( 'Select the button type you want to show in your website.', 'cmb2' ),
		'id'   => $prefix . 'button_type',
		'type'             => 'select',
		'default'             => 'call',
		'options'          => array(
			'call' => __( 'Call Only', '' ),
			'chat' => __( 'Chat Only', '' ),
			'dropdown' => __( 'Call + Chat Dropdown', '' ),
		),	
	) );		
	$cmb_demo->add_field( array(
		'name' => __( 'Padding Left (optional)', 'cmb2' ),
		'desc' => __( 'IN PX. Enter a integer value to Set the left padding (space) of the button using the option.', 'cmb2' ),
		'id'   => $prefix . 'padding_left',
		'type' => 'text_number',
	) );	

	$cmb_demo->add_field( array(
		'name' => __( 'Padding Top (optional)', 'cmb2' ),
		'desc' => __( 'IN PX. Enter a integer value to Set the top padding (space) of the button using the option.', 'cmb2' ),
		'id'   => $prefix . 'padding_top',
		'type' => 'text_number',
	) );

}
//------------------number type below adding-----------------
// render numbers
add_action( 'cmb2_render_text_number', 'msbg_cmb_render_text_number', 10, 5 );
function msbg_cmb_render_text_number( $field, $escaped_value, $object_id, $object_type, $field_type_object ) {
    echo $field_type_object->input( array( 'class' => 'cmb2-text-small', 'type' => 'number' ) );
}

// sanitize the field
add_filter( 'cmb2_sanitize_text_number', 'msbg_cmb2_sanitize_text_number', 10, 2 );
function msbg_cmb2_sanitize_text_number( $null, $new ) {
    $new = preg_replace( "/[^0-9]/", "", $new );

    return $new;
}
// ----------Email field adding ---------------------------------

function cmb2_render_callback_for_text_email( $field, $escaped_value, $object_id, $object_type, $field_type_object ) {
    echo $field_type_object->input( array( 'type' => 'email' ) );
}
add_action( 'cmb2_render_text_email', 'cmb2_render_callback_for_text_email', 10, 5 );


function cmb2_sanitize_text_email_callback( $override_value, $value ) {
    // not an email?
    if ( ! is_email( $value ) ) {
        // Empty the value
        $value = '';
    }
    return $value;
}
add_filter( 'cmb2_sanitize_text_email', 'cmb2_sanitize_text_email_callback', 10, 2 );